@@ -7,12 +7,6 @@ use Zanas::Presentation::MSIE_5;
 #use Zanas::Presentation::Mozilla_3;
 use Zanas::Presentation::Unsupported;
 
-=head1 NAME
-
-Presentation.pm -    .
-
-=cut
-
 ################################################################################
 
 sub dump_attributes {
@@ -29,24 +23,6 @@ sub trunc_string {
 
 ################################################################################
 
-=head1 create_url
-
-  C<url>      C<CGI>-,     ,     C<'_'>.
-
-=head2 
-
-
-	#  url: /?sid=666&type=foo&_x=1&id=1
-
-	my $url = create_url (id => 2, n => 5);
-
-	#  $url eq '/?sid=666&type=foo&id=2&n=5'
-
-
-=cut
-
-################################################################################
-
 sub create_url {
 
 	my %over = @_;	
@@ -131,24 +107,6 @@ sub order {
 
 ################################################################################
 
-=head1 check_href
-
-   C<href>  ,   ,     C<sid>  C<_salt>.  C<javascript>-    .
-
-=head2 
-
-
-	#  $options: {href => '/?type=foo&_x=1&id=1'}, sid = 666
-
-	check_href ($options);
-
-	#  $options: {href => '/?type=foo&_x=1&id=1&sid=666&_salt=0.357357387387'}
-
-
-=cut
-
-################################################################################
-
 sub check_href {
 
 	my ($options) = @_;
